1.0.0 API documentation: vector_bool3_precision.hpp Source File

| 1.0.0 API documentation

vector_bool3_precision.hpp
Go to the documentation of this file.
1
4 #pragma once
5 #include "../detail/type_vec3.hpp"
6
7 namespace glm
8 {
11
16 typedef vec<3, bool, highp> highp_bvec3;
17
22 typedef vec<3, bool, mediump> mediump_bvec3;
23
28 typedef vec<3, bool, lowp> lowp_bvec3;
29
31 }//namespace glm
glm::highp_bvec3
vec< 3, bool, highp > highp_bvec3
3 components vector of high qualifier bool numbers.
Definition: vector_bool3_precision.hpp:16
glm::lowp_bvec3
vec< 3, bool, lowp > lowp_bvec3
3 components vector of low qualifier bool numbers.
Definition: vector_bool3_precision.hpp:28
glm::mediump_bvec3
vec< 3, bool, mediump > mediump_bvec3
3 components vector of medium qualifier bool numbers.
Definition: vector_bool3_precision.hpp:22